export { E as Endpoint, c as createRoute } from './route-Bcly2cdN.js';
import 'zod';

declare const RPC_CODE_TO_HTTP_STATUS_CODE: {
    readonly PARSE_ERROR: 400;
    readonly BAD_REQUEST: 400;
    readonly UNAUTHORIZED: 401;
    readonly NOT_FOUND: 404;
    readonly FORBIDDEN: 403;
    readonly METHOD_NOT_SUPPORTED: 405;
    readonly TIMEOUT: 408;
    readonly CONFLICT: 409;
    readonly PRECONDITION_FAILED: 412;
    readonly PAYLOAD_TOO_LARGE: 413;
    readonly UNSUPPORTED_MEDIA_TYPE: 415;
    readonly UNPROCESSABLE_CONTENT: 422;
    readonly TOO_MANY_REQUESTS: 429;
    readonly CLIENT_CLOSED_REQUEST: 499;
    readonly INTERNAL_SERVER_ERROR: 500;
    readonly NOT_IMPLEMENTED: 501;
};
type RPC_ERROR_CODE_KEY = keyof typeof RPC_CODE_TO_HTTP_STATUS_CODE;
type ErrorOpts = {
    code: RPC_ERROR_CODE_KEY;
    type?: string;
    title?: string;
    detail?: string;
    extensions?: Record<string, any>;
    cause?: unknown;
};
/**
 * Follwoing the Problem Details for HTTP APIs specification RFC 9457 (https://datatracker.ietf.org/doc/html/rfc9457)
 */
declare class RPCError extends Error {
    readonly code: "PARSE_ERROR" | "BAD_REQUEST" | "UNAUTHORIZED" | "NOT_FOUND" | "FORBIDDEN" | "METHOD_NOT_SUPPORTED" | "TIMEOUT" | "CONFLICT" | "PRECONDITION_FAILED" | "PAYLOAD_TOO_LARGE" | "UNSUPPORTED_MEDIA_TYPE" | "UNPROCESSABLE_CONTENT" | "TOO_MANY_REQUESTS" | "CLIENT_CLOSED_REQUEST" | "INTERNAL_SERVER_ERROR" | "NOT_IMPLEMENTED";
    readonly type: string | undefined;
    readonly title: string;
    readonly detail: string | undefined;
    readonly extensions: Record<string, any> | undefined;
    constructor(opts: ErrorOpts);
}

export { RPCError };
