import z, { ZodObject, ZodOptional, ZodType } from 'zod';

type DataTransformer = {
    serialize: (object: any) => any;
    deserialize: (object: any) => any;
};
type Router = {
    [key: string]: Endpoint | Router;
};
type BaseCtx<Req = unknown, Res = unknown> = {
    req: Req;
    res: Res;
};

type Ctx<AdapterContext extends BaseCtx, InputSchema = unknown> = {
    req: AdapterContext['req'];
    res: AdapterContext['res'];
    input: InputSchema;
};
type IsNever<T> = [T] extends [never] ? true : false;
type IsAny<T> = 0 extends 1 & T ? true : false;
type FormatInput<T, U> = IsNever<T> extends true ? U : T & U;
type Event = 'afterMiddlewares';
type EventCbCtx<AdapterContext extends BaseCtx, MiddlewareContext = {}> = Pick<Ctx<AdapterContext>, 'req' | 'res'> & MiddlewareContext & Record<string, any>;
declare class Endpoint<Input extends {
    method: 'GET' | 'POST';
    input?: any;
    output: any;
    handler: (ctx: any) => any;
    middlewares: ((ctx: any) => Record<keyof any, unknown> | void)[];
} = any> {
    method: Input['method'];
    input: Input['input'];
    output: Input['output'];
    handler: Input['handler'];
    middlewares: Input['middlewares'];
    constructor(input: Input);
}
declare class Route<AdapterContext extends BaseCtx, InputSchema = never, OutputSchema = any, MiddlewareContext = {}> {
    #private;
    constructor(data?: any);
    input<Schema extends ZodObject<any> | ZodOptional<ZodObject<any>>>(schema: Schema): Route<AdapterContext, FormatInput<InputSchema, z.TypeOf<Schema>> extends infer T ? { [K in keyof T]: FormatInput<InputSchema, z.TypeOf<Schema>>[K]; } : never, OutputSchema, MiddlewareContext>;
    output<Schema extends ZodType>(schema: Schema): Route<AdapterContext, InputSchema, z.TypeOf<Schema>, MiddlewareContext>;
    middleware<const T extends Record<string, unknown> | void>(middleware: (ctx: Ctx<AdapterContext, InputSchema> & MiddlewareContext) => T | Promise<T>): Route<AdapterContext, InputSchema, OutputSchema, MiddlewareContext & Awaited<T> extends infer T_1 ? { [K in keyof T_1]: (MiddlewareContext & Awaited<T>)[K]; } : never>;
    post<T extends OutputSchema>(cb: (ctx: Ctx<AdapterContext, InputSchema> & MiddlewareContext) => T | Promise<T>): Endpoint<{
        method: "POST";
        input: InputSchema;
        output: IsAny<OutputSchema> extends true ? T : OutputSchema;
        handler: (ctx: Ctx<AdapterContext, InputSchema> & MiddlewareContext) => T | Promise<T>;
        middlewares: ((ctx: Ctx<AdapterContext, InputSchema> & MiddlewareContext) => any)[];
    }>;
    get<T extends OutputSchema>(cb: (ctx: Ctx<AdapterContext, InputSchema> & MiddlewareContext) => T | Promise<T>): Endpoint<{
        method: "GET";
        input: InputSchema;
        output: IsAny<OutputSchema> extends true ? T : OutputSchema;
        handler: (ctx: Ctx<AdapterContext, InputSchema> & MiddlewareContext) => T | Promise<T>;
        middlewares: ((ctx: Ctx<AdapterContext, InputSchema> & MiddlewareContext) => any)[];
    }>;
    on(event: Event, cb: (ctx: EventCbCtx<AdapterContext, MiddlewareContext>) => void | Promise<void>): void;
}
declare function createRoute<AdapterContext extends BaseCtx>(): Route<AdapterContext, never, any, {}>;

export { type BaseCtx as B, type DataTransformer as D, Endpoint as E, type Router as R, createRoute as c };
